@@ -286,7 +286,7 @@ class Stack:
         return Stack(self.stack)
 
     def find(self, function):
-        return [item for item in self.stack if function(item)].copy()
+        return list(filter(lambda x: function(x), self.stack)).copy()
 
     def exists(self, function):
         return len(self.find(function=function)) > 0
