@@ -196,6 +196,26 @@ class DSRequest(RPCRequest):
     def get_data_wrapped(self, excluded_keys=['grid'], cls=Wrapper):
         return cls(**self.get_data(excluded_keys=excluded_keys))
 
+    def get_transaction_data(self, excluded_keys=['grid']):
+        data = self.get_data(excluded_keys=excluded_keys)
+        if isinstance(data, dict):
+            transaction = data.get('transaction')
+            if isinstance(transaction, dict):
+                return transaction.get('operations')
+            else:
+                return [data]
+        return None
+
+    def get_transaction_old_data(self, excluded_keys=['grid']):
+        data = self.get_old_data(excluded_keys=excluded_keys)
+        if isinstance(data, dict):
+            transaction = data.get('transaction')
+            if isinstance(transaction, dict):
+                return transaction.get('operations')
+            else:
+                return [data]
+        return None
+
     def get_old_data(self, excluded_keys=['grid']):
         res = None
         if isinstance(self.json, dict):
