@@ -11,5 +11,6 @@ class RPCRequest:
                 else:
                     try:
                         setattr(self, key, RPCRequest(value) if isinstance(value, dict) else value)
-                    except AttributeError:
+                    except AttributeError as ex:
                         logger.warning(f'key:{key} value: {value} do not recorded')
+                        logger.warning(ex)
