@@ -1,4 +1,5 @@
 import logging
+from time import sleep
 
 from django.conf import settings
 from django.core.management import BaseCommand
@@ -38,9 +39,9 @@ class Command(BaseCommand):
                 progress.show(title=f'Тест {i}', label_contents=f'Text {i}', id=i)
 
             for i in range(qty):
-                for j in range(qty):
+                for j in range(11):
                     progress.setPercentsDone(percent=j * 10, id=i)
 
-        if mode == 'close':
-            for i in range(qty):
-                progress.close(id=i)
+            # sleep(3)
+            # for i in range(qty):
+            #     progress.close(id=i)
