@@ -320,7 +320,11 @@ class CommonQuerySet(QuerySet):
         if data is not None:
             for key, value in data.items():
                 if value is not None and key != 'full_name':
-                    setAttr(_data, key, value)
+                    if isinstance(value, list):
+                        if len(value) > 0:
+                            setAttr(_data, key, value)
+                    else:
+                        setAttr(_data, key, value)
         data = _data
         delAttr(data, 'ts')
 
@@ -356,7 +360,7 @@ class CommonQuerySet(QuerySet):
             for key, value in data.items():
                 if isinstance(value, Bit):
                     criteria.add(Q(**{f"{key}": value}), operator)
-                elif isinstance(value, list):
+                elif isinstance(value, list) :
                     criteria.add(Q(**{f"{key}__in": value}), operator)
                 else:
                     if textMatchStyle == "iexact" and isinstance(value, int):
