@@ -58,6 +58,11 @@ class AuditQuerySet(CommonQuerySet):
             setAttr(kwargs, 'lastmodified', timezone.now())
         return super().update(**kwargs)
 
+    def getOptional(self, *args, **kwargs):
+        try:
+            return self.get(*args, **kwargs)
+        except self.model.DoesNotExist:
+            return None
 
 class AuditManager(CommonManager):
     def __init__(self, *args, **kwargs):
@@ -78,13 +83,11 @@ class AuditManager(CommonManager):
     def soft_restore(self):
         return self.get_queryset().soft_restore()
 
-
-class Manager(CommonManager):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-    def get_queryset(self):
-        return AuditQuerySet(model=self.model)
+    def getOptional(self, *args, **kwargs):
+        try:
+            return self.get(*args, **kwargs)
+        except self.model.DoesNotExist:
+            return None
 
 
 class AuditModel(Model):
