@@ -31,8 +31,7 @@ class AuditModelExManager(AuditManager):
 
 
 class AuditModelEx(AuditModel):
-    creator = ForeignKeyProtect(User)
-
+    creator = ForeignKeyProtect(User, related_name='AuditModelEx_creator')
     objects = AuditModelExManager()
 
     def __str__(self):
